From 2ba06a6414be2654b5a4f1cfae2b28e36cd1bcab Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Tue, 19 Dec 2023 16:20:41 +0100
Subject: [PATCH v2 2/2] meson: Make gzip and tar optional

They are only used for some tests.  The tests are already set to skip
as appropriate if they are not available.
---
 contrib/basebackup_to_shell/meson.build | 4 ++--
 meson.build                             | 4 ++--
 src/bin/pg_basebackup/meson.build       | 4 ++--
 src/bin/pg_dump/meson.build             | 2 +-
 src/bin/pg_verifybackup/meson.build     | 4 ++--
 5 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/contrib/basebackup_to_shell/meson.build b/contrib/basebackup_to_shell/meson.build
index a5488c3023..331ee1c9be 100644
--- a/contrib/basebackup_to_shell/meson.build
+++ b/contrib/basebackup_to_shell/meson.build
@@ -24,7 +24,7 @@ tests += {
     'tests': [
       't/001_basic.pl',
     ],
-    'env': {'GZIP_PROGRAM': gzip.path(),
-            'TAR': tar.path()},
+    'env': {'GZIP_PROGRAM': gzip.found() ? gzip.path() : '',
+            'TAR': tar.found() ? tar.path() : '' },
   },
 }
diff --git a/meson.build b/meson.build
index 3162d0343b..4e98cbefe4 100644
--- a/meson.build
+++ b/meson.build
@@ -333,8 +333,8 @@ flex = find_program(get_option('FLEX'), native: true, version: '>= 2.5.35')
 bison = find_program(get_option('BISON'), native: true, version: '>= 2.3')
 sed = find_program(get_option('SED'), 'sed', native: true, required: false)
 prove = find_program(get_option('PROVE'), native: true, required: false)
-tar = find_program(get_option('TAR'), native: true)
-gzip = find_program(get_option('GZIP'), native: true)
+tar = find_program(get_option('TAR'), native: true, required: false)
+gzip = find_program(get_option('GZIP'), native: true, required: false)
 program_lz4 = find_program(get_option('LZ4'), native: true, required: false)
 openssl = find_program(get_option('OPENSSL'), native: true, required: false)
 program_zstd = find_program(get_option('ZSTD'), native: true, required: false)
diff --git a/src/bin/pg_basebackup/meson.build b/src/bin/pg_basebackup/meson.build
index c426173db3..5445903a5b 100644
--- a/src/bin/pg_basebackup/meson.build
+++ b/src/bin/pg_basebackup/meson.build
@@ -80,8 +80,8 @@ tests += {
   'sd': meson.current_source_dir(),
   'bd': meson.current_build_dir(),
   'tap': {
-    'env': {'GZIP_PROGRAM': gzip.path(),
-            'TAR': tar.path(),
+    'env': {'GZIP_PROGRAM': gzip.found() ? gzip.path() : '',
+            'TAR': tar.found() ? tar.path() : '',
             'LZ4': program_lz4.found() ? program_lz4.path() : '',
     },
     'tests': [
diff --git a/src/bin/pg_dump/meson.build b/src/bin/pg_dump/meson.build
index b6603e26a5..77d162cad4 100644
--- a/src/bin/pg_dump/meson.build
+++ b/src/bin/pg_dump/meson.build
@@ -90,7 +90,7 @@ tests += {
   'bd': meson.current_build_dir(),
   'tap': {
     'env': {
-      'GZIP_PROGRAM': gzip.path(),
+      'GZIP_PROGRAM': gzip.found() ? gzip.path() : '',
       'LZ4': program_lz4.found() ? program_lz4.path() : '',
       'ZSTD': program_zstd.found() ? program_zstd.path() : '',
       'with_icu': icu.found() ? 'yes' : 'no',
diff --git a/src/bin/pg_verifybackup/meson.build b/src/bin/pg_verifybackup/meson.build
index 58f780d1a6..8049011566 100644
--- a/src/bin/pg_verifybackup/meson.build
+++ b/src/bin/pg_verifybackup/meson.build
@@ -22,8 +22,8 @@ tests += {
   'sd': meson.current_source_dir(),
   'bd': meson.current_build_dir(),
   'tap': {
-    'env': {'GZIP_PROGRAM': gzip.path(),
-            'TAR': tar.path(),
+    'env': {'GZIP_PROGRAM': gzip.found() ? gzip.path() : '',
+            'TAR': tar.found() ? tar.path() : '',
             'LZ4': program_lz4.found() ? program_lz4.path() : '',
             'ZSTD': program_zstd.found() ? program_zstd.path() : ''},
     'tests': [
-- 
2.43.0

